@@ -5,7 +5,7 @@ import re
 from collections import Counter
 from dataclasses import dataclass
 from itertools import chain
-from typing import TYPE_CHECKING, Any, Dict, Iterable, Iterator, List, cast
+from typing import TYPE_CHECKING, Dict, Iterable, Iterator, List, cast
 
 from tox.config.loader.str_convert import StrConvert
 from tox.config.types import EnvList
@@ -46,10 +46,10 @@ class CliEnv:
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}({'' if self.is_default_list else repr(str(self))})"
 
-    def __eq__(self, other: Any) -> bool:
-        return type(self) == type(other) and self._names == other._names
+    def __eq__(self, other: object) -> bool:
+        return type(self) == type(other) and self._names == other._names  # type: ignore[attr-defined]
 
-    def __ne__(self, other: Any) -> bool:
+    def __ne__(self, other: object) -> bool:
         return not (self == other)
 
     @property
@@ -152,6 +152,15 @@ class EnvSelector:
         elif self._cli_envs.is_all:
             everything_active = True
         else:
+            cli_envs_not_in_config = set(self._cli_envs) - set(self._state.conf)
+            if cli_envs_not_in_config:
+                # allow cli_envs matching ".pkg" and starting with "py" to be implicitly created.
+                disallowed_cli_envs = [
+                    env for env in cli_envs_not_in_config if not env.startswith("py") and env not in (".pkg",)
+                ]
+                if disallowed_cli_envs:
+                    msg = f"provided environments not found in configuration file: {disallowed_cli_envs}"
+                    raise HandledError(msg)
             yield self._cli_envs, True
         yield self._state.conf, everything_active
         label_envs = dict.fromkeys(chain.from_iterable(self._state.conf.core["labels"].values()))
