@@ -1,4 +1,4 @@
-"""Adapted from the pip code base"""
+"""Adapted from the pip code base."""
 from __future__ import annotations
 
 import os
@@ -31,7 +31,7 @@ DEFAULT_INDEX_URL = "https://pypi.org/simple"
 
 
 class ParsedRequirement:
-    def __init__(self, req: str, options: dict[str, Any], from_file: str, lineno: int) -> None:
+    def __init__(self, req: str, options: dict[str, Any], from_file: str, lineno: int) -> None:  # noqa: PLR0912
         req = req.encode("utf-8").decode("utf-8")
         try:
             self._requirement: Requirement | Path | str = Requirement(req)
@@ -44,7 +44,7 @@ class ParsedRequirement:
                 match = _EXTRA_PATH.fullmatch(Path(req).name)
                 if match:
                     for extra in match.group(2).split(","):
-                        extra = extra.strip()
+                        extra = extra.strip()  # noqa: PLW2901
                         if not extra:
                             continue
                         if not _EXTRA_ELEMENT.fullmatch(extra):
@@ -110,7 +110,14 @@ class ParsedRequirement:
 
 
 class ParsedLine:
-    def __init__(self, filename: str, lineno: int, args: str, opts: Namespace, constraint: bool) -> None:
+    def __init__(  # noqa: PLR0913
+        self,
+        filename: str,
+        lineno: int,
+        args: str,
+        opts: Namespace,
+        constraint: bool,  # noqa: FBT001
+    ) -> None:
         self.filename = filename
         self.lineno = lineno
         self.opts = opts
@@ -129,7 +136,7 @@ class ParsedLine:
 
 
 class RequirementsFile:
-    def __init__(self, path: Path, constraint: bool) -> None:
+    def __init__(self, path: Path, constraint: bool) -> None:  # noqa: FBT001
         self._path = path
         self._is_constraint: bool = constraint
         self._opt = Namespace()
@@ -169,14 +176,14 @@ class RequirementsFile:
             self._extend_parser(self._parser_private)
         return self._parser_private
 
-    def _extend_parser(self, parser: ArgumentParser) -> None:  # noqa: U100
+    def _extend_parser(self, parser: ArgumentParser) -> None:
         ...
 
     def _ensure_requirements_parsed(self) -> None:
         if self._requirements is None:
             self._requirements = self._parse_requirements(opt=self._opt, recurse=True)
 
-    def _parse_requirements(self, opt: Namespace, recurse: bool) -> list[ParsedRequirement]:
+    def _parse_requirements(self, opt: Namespace, recurse: bool) -> list[ParsedRequirement]:  # noqa: FBT001
         result, found = [], set()
         for parsed_line in self._parse_and_recurse(str(self._path), self.is_constraint, recurse):
             if parsed_line.is_requirement:
@@ -199,7 +206,12 @@ class RequirementsFile:
             return 1, between
         return 0, between
 
-    def _parse_and_recurse(self, filename: str, constraint: bool, recurse: bool) -> Iterator[ParsedLine]:
+    def _parse_and_recurse(
+        self,
+        filename: str,
+        constraint: bool,  # noqa: FBT001
+        recurse: bool,  # noqa: FBT001
+    ) -> Iterator[ParsedLine]:
         for line in self._parse_file(filename, constraint):
             if not line.is_requirement and (line.opts.requirements or line.opts.constraints):
                 if line.opts.requirements:  # parse a nested requirements file
@@ -209,17 +221,16 @@ class RequirementsFile:
                 if _SCHEME_RE.search(filename):  # original file is over http
                     req_path = urllib.parse.urljoin(filename, req_path)  # do a url join so relative paths work
                 elif not _SCHEME_RE.search(req_path):  # original file and nested file are paths
-                    # do a join so relative paths work
-                    req_path = os.path.join(os.path.dirname(filename), req_path)
+                    req_path = str(Path(filename).parent / req_path)  # do a join so relative paths work
                 if recurse:
-                    yield from self._req_parser._parse_and_recurse(req_path, nested_constraint, recurse)
+                    yield from self._req_parser._parse_and_recurse(req_path, nested_constraint, recurse)  # noqa: SLF001
                 else:
                     line.filename = req_path
                     yield line
             else:
                 yield line
 
-    def _parse_file(self, url: str, constraint: bool) -> Iterator[ParsedLine]:
+    def _parse_file(self, url: str, constraint: bool) -> Iterator[ParsedLine]:  # noqa: FBT001
         content = self._get_file_content(url)
         for line_number, line in self._pre_process(content):
             args_str, opts = self._parse_line(line)
@@ -234,16 +245,16 @@ class RequirementsFile:
         """
         scheme = get_url_scheme(url)
         if scheme in ["http", "https"]:
-            with urlopen(url) as response:
-                text = self._read_decode(response)
-                return text
+            with urlopen(url) as response:  # noqa: S310
+                return self._read_decode(response)
         elif scheme == "file":
             url = url_to_path(url)
         try:
-            with open(url, "rb") as file_handler:
+            with Path(url).open("rb") as file_handler:
                 text = self._read_decode(file_handler)
         except OSError as exc:
-            raise ValueError(f"Could not open requirements file {url}: {exc}") from exc
+            msg = f"Could not open requirements file {url}: {exc}"
+            raise ValueError(msg) from exc
         return text
 
     @staticmethod
@@ -252,19 +263,18 @@ class RequirementsFile:
         if not raw:
             return ""
         codec = chardet.detect(raw)["encoding"]
-        text = raw.decode(codec)
-        return text
+        return raw.decode(codec)
 
     def _pre_process(self, content: str) -> ReqFileLines:
-        """Split, filter, and join lines, and return a line iterator
+        """
+        Split, filter, and join lines, and return a line iterator.
 
         :param content: the content of the requirements file
         """
         lines_enum: ReqFileLines = enumerate(content.splitlines(), start=1)
         lines_enum = self._join_lines(lines_enum)
         lines_enum = self._ignore_comments(lines_enum)
-        lines_enum = self._expand_env_variables(lines_enum)
-        return lines_enum
+        return self._expand_env_variables(lines_enum)
 
     def _parse_line(self, line: str) -> tuple[str, Namespace]:
         args_str, options_str = self._break_args_options(line)
@@ -286,7 +296,12 @@ class RequirementsFile:
             req_options["hash"] = hash_values
         return ParsedRequirement(line.requirement, req_options, line.filename, line.lineno)
 
-    def _merge_option_line(self, base_opt: Namespace, opt: Namespace, filename: str) -> None:  # noqa: C901
+    def _merge_option_line(  # noqa: C901, PLR0912, PLR0915
+        self,
+        base_opt: Namespace,
+        opt: Namespace,
+        filename: str,
+    ) -> None:
         # percolate options upward
         if opt.requirements:
             if not hasattr(base_opt, "requirements"):
@@ -305,7 +320,7 @@ class RequirementsFile:
                 base_opt.features_enabled = []
             for feature in opt.features_enabled:
                 if feature not in base_opt.features_enabled:
-                    base_opt.features_enabled.append(feature)
+                    base_opt.features_enabled.append(feature)  # noqa: PERF401
             base_opt.features_enabled.sort()
         if opt.index_url:
             if getattr(base_opt, "index_url", []):
@@ -321,16 +336,15 @@ class RequirementsFile:
                 if url not in base_opt.index_url:
                     base_opt.index_url.extend(opt.extra_index_url)
         if opt.find_links:
-            # FIXME: it would be nice to keep track of the source of the find_links: support a find-links local path
             # relative to a requirements file.
-            if not hasattr(base_opt, "index_url"):  # pragma: no branch
+            if not hasattr(base_opt, "find_links"):
                 base_opt.find_links = []
             value = opt.find_links[0]
-            req_dir = os.path.dirname(os.path.abspath(filename))
-            relative_to_reqs_file = os.path.join(req_dir, value)
-            if os.path.exists(relative_to_reqs_file):
-                value = relative_to_reqs_file  # pragma: no cover
-            if value not in base_opt.find_links:  # pragma: no branch
+            req_dir = Path(filename).absolute().parent
+            relative_to_reqs_file = req_dir / value
+            if os.path.exists(str(relative_to_reqs_file)):  # noqa: PTH110 # Path.exists fails on win32 <=3.7 with URI
+                value = str(relative_to_reqs_file)  # pragma: no cover
+            if value not in base_opt.find_links:
                 base_opt.find_links.append(value)
         if opt.pre:
             base_opt.pre = True
@@ -358,10 +372,9 @@ class RequirementsFile:
         for token in tokens:
             if token.startswith("-"):  # both `-` and `--` accepted
                 break
-            else:
-                args.append(token)
-                options.pop(0)
-        return " ".join(args), " ".join(options)
+            args.append(token)
+            options.pop(0)
+        return " ".join(args).strip(), " ".join(options)
 
     @staticmethod
     def _join_lines(lines_enum: ReqFileLines) -> ReqFileLines:
@@ -374,10 +387,10 @@ class RequirementsFile:
         for line_number, line in lines_enum:
             if not line.endswith("\\") or _COMMENT_RE.match(line):
                 if _COMMENT_RE.match(line):
-                    line = f" {line}"  # this ensures comments are always matched later
+                    line = f" {line}"  # noqa: PLW2901 # this ensures comments are always matched later
                 if new_line:
                     new_line.append(line)
-                    assert primary_line_number is not None
+                    assert primary_line_number is not None  # noqa: S101
                     yield primary_line_number, "".join(new_line)
                     new_line = []
                 else:
@@ -388,21 +401,21 @@ class RequirementsFile:
                 new_line.append(line.strip("\\"))
         # last line contains \
         if new_line:
-            assert primary_line_number is not None
+            assert primary_line_number is not None  # noqa: S101
             yield primary_line_number, "".join(new_line)
 
     @staticmethod
     def _ignore_comments(lines_enum: ReqFileLines) -> ReqFileLines:
         """Strips comments and filter empty lines."""
         for line_number, line in lines_enum:
-            line = _COMMENT_RE.sub("", line)
-            line = line.strip()
-            if line:
-                yield line_number, line
+            processed_line = _COMMENT_RE.sub("", line).strip()
+            if processed_line:
+                yield line_number, processed_line
 
     @staticmethod
     def _expand_env_variables(lines_enum: ReqFileLines) -> ReqFileLines:
-        """Replace all environment variables that can be retrieved via `os.getenv`.
+        """
+        Replace all environment variables that can be retrieved via `os.getenv`.
 
         The only allowed format for environment variables defined in the requirement file is `${MY_VARIABLE_1}` to
         ensure two things:
@@ -415,12 +428,13 @@ class RequirementsFile:
         <http://pubs.opengroup.org/onlinepubs/9699919799/>`_ and are limited to uppercase letter, digits and the `_`.
         """
         for line_number, line in lines_enum:
-            for env_var, var_name in _ENV_VAR_RE.findall(line):
+            expanded_line = line
+            for env_var, var_name in _ENV_VAR_RE.findall(expanded_line):
                 value = os.getenv(var_name)
                 if not value:
                     continue
-                line = line.replace(env_var, value)
-            yield line_number, line
+                expanded_line = expanded_line.replace(env_var, value)
+            yield line_number, expanded_line
 
     @property
     def as_root_args(self) -> list[str]:
@@ -435,7 +449,7 @@ class RequirementsFile:
             self._as_root_args = result
         return self._as_root_args
 
-    def _option_to_args(self, opt: Namespace) -> list[str]:
+    def _option_to_args(self, opt: Namespace) -> list[str]:  # noqa: C901, PLR0912
         result: list[str] = []
         for req in getattr(opt, "requirements", []):
             result.extend(("-r", req))
