@@ -1,16 +1,21 @@
 from __future__ import annotations
 
 import sys
-from pathlib import Path
-from typing import Callable
+from typing import TYPE_CHECKING, Callable
+from unittest.mock import patch
 
 import pytest
-from pytest_mock import MockerFixture
 
-from tox.pytest import ToxProjectCreator
 from tox.tox_env.errors import Fail
 from tox.tox_env.python.api import Python
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from pytest_mock import MockerFixture
+
+    from tox.pytest import ToxProjectCreator
+
 
 def test_requirements_txt(tox_project: ToxProjectCreator) -> None:
     prj = tox_project(
@@ -64,11 +69,11 @@ def test_diff_msg_added_removed_changed() -> None:
     before = {"A": "1", "F": "8", "C": "3", "D": "4", "E": "6"}
     after = {"G": "9", "B": "2", "C": "3", "D": "5", "E": "7"}
     expected = "python added A='1' | F='8', removed G='9' | B='2', changed D='5'->'4' | E='7'->'6'"
-    assert Python._diff_msg(before, after) == expected
+    assert Python._diff_msg(before, after) == expected  # noqa: SLF001
 
 
 def test_diff_msg_no_diff() -> None:
-    assert Python._diff_msg({}, {}) == "python "
+    assert Python._diff_msg({}, {}) == "python "  # noqa: SLF001
 
 
 @pytest.mark.parametrize(
@@ -111,7 +116,7 @@ def test_extract_base_python(env: str, base_python: str | None) -> None:
     ids=lambda a: "|".join(a) if isinstance(a, list) else str(a),
 )
 def test_base_python_env_no_conflict(env: str, base_python: list[str], ignore_conflict: bool) -> None:
-    result = Python._validate_base_python(env, base_python, ignore_conflict)
+    result = Python._validate_base_python(env, base_python, ignore_conflict)  # noqa: SLF001
     assert result is base_python
 
 
@@ -139,12 +144,12 @@ def test_base_python_env_conflict(
     ignore_conflict: bool,
 ) -> None:
     if ignore_conflict:
-        result = Python._validate_base_python(env, base_python, ignore_conflict)
+        result = Python._validate_base_python(env, base_python, ignore_conflict)  # noqa: SLF001
         assert result == [expected]
     else:
         msg = f"env name {env} conflicting with base python {conflict[0]}"
         with pytest.raises(Fail, match=msg):
-            Python._validate_base_python(env, base_python, ignore_conflict)
+            Python._validate_base_python(env, base_python, ignore_conflict)  # noqa: SLF001
 
 
 @pytest.mark.parametrize("ignore_conflict", [True, False, None])
@@ -216,11 +221,59 @@ def test_python_set_hash_seed_incorrect(tox_project: ToxProjectCreator) -> None:
     assert "tox run: error: argument --hashseed: invalid literal for int() with base 10: 'ok'" in result.err
 
 
+def test_python_use_hash_seed_from_env(tox_project: ToxProjectCreator) -> None:
+    ini = "[testenv]\npackage=skip"
+    with patch.dict("os.environ", {"PYTHONHASHSEED": "13"}):
+        result = tox_project({"tox.ini": ini}).run("c", "-e", "py", "-k", "setenv")
+        result.assert_success()
+        assert "PYTHONHASHSEED=13" in result.out
+
+
+def test_python_hash_seed_from_env_random(tox_project: ToxProjectCreator) -> None:
+    ini = "[testenv]\npackage=skip"
+    with patch.dict("os.environ", {"PYTHONHASHSEED": "random"}):
+        result = tox_project({"tox.ini": ini}).run("c", "-e", "py", "-k", "setenv")
+        result.assert_success()
+        assert "PYTHONHASHSEED=" in result.out
+
+
+def test_python_hash_seed_from_env_and_override(tox_project: ToxProjectCreator) -> None:
+    ini = "[testenv]\npackage=skip\ncommands=python -c 'import os; print(os.environ.get(\"PYTHONHASHSEED\"))'"
+    with patch.dict("os.environ", {"PYTHONHASHSEED": "14"}):
+        result = tox_project({"tox.ini": ini}).run("r", "-e", "py", "--hashseed", "15")
+        result.assert_success()
+        assert result.out.splitlines()[1] == "15"
+
+
+def test_python_hash_seed_from_env_and_disable(tox_project: ToxProjectCreator) -> None:
+    ini = "[testenv]\npackage=skip\ncommands=python -c 'import os; print(os.environ.get(\"PYTHONHASHSEED\"))'"
+    with patch.dict("os.environ", {"PYTHONHASHSEED": "16"}):
+        result = tox_project({"tox.ini": ini}).run("r", "-e", "py", "--hashseed", "notset")
+        result.assert_success()
+        assert result.out.splitlines()[1] == "None"
+
+
 @pytest.mark.parametrize("in_ci", [True, False])
 def test_list_installed_deps(in_ci: bool, tox_project: ToxProjectCreator, mocker: MockerFixture) -> None:
-    mocker.patch("tox.tox_env.python.api.is_ci", return_value=in_ci)
+    mocker.patch("tox.session.cmd.run.common.is_ci", return_value=in_ci)
     result = tox_project({"tox.ini": "[testenv]\nskip_install = true"}).run("r", "-e", "py")
     if in_ci:
         assert "pip==" in result.out
     else:
         assert "pip==" not in result.out
+
+
+@pytest.mark.parametrize("list_deps", ["--list-dependencies", "--no-list-dependencies"])
+@pytest.mark.parametrize("in_ci", [True, False])
+def test_list_installed_deps_explicit_cli(
+    list_deps: str,
+    in_ci: bool,
+    tox_project: ToxProjectCreator,
+    mocker: MockerFixture,
+) -> None:
+    mocker.patch("tox.session.cmd.run.common.is_ci", return_value=in_ci)
+    result = tox_project({"tox.ini": "[testenv]\nskip_install = true"}).run(list_deps, "r", "-e", "py")
+    if list_deps == "--list-dependencies":
+        assert "pip==" in result.out
+    else:
+        assert "pip==" not in result.out
